==> ejc-purchasingmanagement-api-3.0.0-20220506.130109-54-sources.jar: com/ejianc/business/purchasingmanagement/vo/PurchasedetilVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 采购运输信息明细
 * 
 * @author generator
 * 
 */
public class PurchasedetilVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long shippersVehicleId; // 运输车辆主键
    private String  shippersVehicleName; // 运输车辆名称
    private BigDecimal deliveryQuantity; // 发货数量
    private String numberPlate; // 车牌号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date deliveryTime; // 发货时间
    private BigDecimal tareWeight;    //皮重
    private String phoneNumber; // 手机号
    private String driver; // 司机

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public String getDriver() {
        return driver;
    }

    public void setDriver(String driver) {
        this.driver = driver;
    }

    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }

    public BigDecimal getDeliveryQuantity() {
        return deliveryQuantity;
    }

    public void setDeliveryQuantity(BigDecimal deliveryQuantity) {
        this.deliveryQuantity = deliveryQuantity;
    }



    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }


    @ReferSerialTransfer(referCode="ShippersVehicleRef")
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }
    @ReferDeserialTransfer
    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }


    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getDeliveryTime() {
        return deliveryTime;
    }

    public void setDeliveryTime(Date deliveryTime) {
        this.deliveryTime = deliveryTime;
    }


}

==> ejc-purchasingmanagement-api-3.0.0-20220525.024528-102-sources.jar: com/ejianc/business/purchasingmanagement/vo/PurchasedetilVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.Date;


/**
 * 采购运输信息明细
 * 
 * @author generator
 * 
 */
public class PurchasedetilVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    private Long shippersVehicleId; // 运输车辆主键
    private String  shippersVehicleName; // 运输车辆名称
    private BigDecimal deliveryQuantity; // 发货数量
    private String numberPlate; // 车牌号
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date deliveryTime; // 发货时间
    private BigDecimal tareWeight;    //皮重
    private String phoneNumber; // 手机号
    private String driver; // 司机
    private Long materialId; // 原材类主键
    private String materialName; // 原材类名称
    private Integer status; // 是否收货(1:是,0:否)
    private Long purchasetransportationId; // 主表主键

    public Long getPurchasetransportationId() {
        return purchasetransportationId;
    }

    public void setPurchasetransportationId(Long purchasetransportationId) {
        this.purchasetransportationId = purchasetransportationId;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public String getDriver() {
        return driver;
    }

    public void setDriver(String driver) {
        this.driver = driver;
    }

    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }

    public BigDecimal getDeliveryQuantity() {
        return deliveryQuantity;
    }

    public void setDeliveryQuantity(BigDecimal deliveryQuantity) {
        this.deliveryQuantity = deliveryQuantity;
    }



    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }


    @ReferSerialTransfer(referCode="ShippersVehicleRef")
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }
    @ReferDeserialTransfer
    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }


    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getDeliveryTime() {
        return deliveryTime;
    }

    public void setDeliveryTime(Date deliveryTime) {
        this.deliveryTime = deliveryTime;
    }


}
